class ID10TException(Exception):
    suffix: str = "Please consult urban dictionary on what that means"
    message: str = "ID10T Exception occurred"
    
    """Base class for all ID10T exceptions."""
    def __init__(self, message="ID10T Exception occurred"):
        self.message = message
        super().__init__(self.message)
    
    def __str__(self):
        return f'{self.message}. {self.suffix}'
    
    def __repr__(self):
        return f'{self.__class__.__name__}({self.message})'
    
    def __doc__(self):
        return f'{self.__class__.__name__} - {self.message}'

class ID10TError(ID10TException):
    pass

class ID10TWarning(Warning):
    suffix: str = "Please consult urban dictionary on what that means"
    message: str = "ID10T Warning occurred"
    
    """Base class for all ID10T warnings."""
    def __init__(self, message="ID10T Warning occurred"):
        self.message = message
        super().__init__(self.message)
    
    def __str__(self):
        return f'{self.message}. {self.suffix}'
    
    def __repr__(self):
        return f'{self.__class__.__name__} ({self.message})'
    
    def __doc__(self):
        return f'{self.__class__.__name__} - {self.message}'


from .interface import ID10TException

class DidntReadDocsException(ID10TException):
    suffix: str = "Please refer to the documentation for more information."
    message: str = "Did you read the documentation?"
    """Exception raised when a user doesn't read the documentation."""

    def __init__(self, message="Did you read the documentation?"):
        self.message = message
        super().__init__(self.message)

class DidntReadDocsError(DidntReadDocsException):
    pass

class DidntUseBrainException(ID10TException):
    suffix: str = "Please refer to your inner computer for more information (\"the brain\")."
    message: str = "Did you use your brain?"
    """Exception raised when a user doesn't use their brain."""
    def __init__(self, message="Did you use your brain?"):
        self.message = message
        super().__init__(self.message)

class DidntUseBrainError(DidntUseBrainException):
    pass

class BrainFartException(ID10TException):
    suffix: str = "Please refer to your inner computer for more information (\"the brain\")."
    message: str = "Did you have a brain fart?"
    """Exception raised when a user has a brain fart."""
    def __init__(self, message="Did you have a brain fart?"):
        self.message = message
        super().__init__(self.message)

class BrainFartError(BrainFartException):
    pass

class WasntVerySmartException(ID10TException):
    suffix: str = "Please re-think your life choices"
    message: str = "That wasn't very smart, was it?"
    
    """Exception raised when a choice made by the user isn't very smart."""
    def __init__(self, message="That wasn't very smart, was it?"):
        self.message = message
        super().__init__(self.message)

class WasntVerySmartError(WasntVerySmartException):
    pass


from .interface import ID10TError, ID10TException, ID10TWarning
from .errors import DidntReadDocsError, DidntReadDocsException, DidntUseBrainError, DidntUseBrainException, WasntVerySmartError, WasntVerySmartException, BrainFartError, BrainFartException
from .warnings import DidntReadDocsWarning, DidntUseBrainWarning, WasntVerySmartWarning, BrainFartWarning

# Add to __all__ for public API
__all__ = [
    "ID10TError",
    "ID10TException",
    "ID10TWarning",
    "DidntReadDocsError",
    "DidntReadDocsException",
    "DidntUseBrainError",
    "DidntUseBrainException",
    "WasntVerySmartError",
    "WasntVerySmartException",
    "BrainFartError",
    "BrainFartException",
    "DidntReadDocsWarning",
    "DidntUseBrainWarning",
    "WasntVerySmartWarning",
    "BrainFartWarning",
]
    


#!/usr/bin/env python3
import os

from setuptools import setup, find_packages

repository_name = 'id10t'
module_name = 'id10terr'
python_min_version = ">=3.1"

required_packages = []
about = {}
here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'src', module_name, '__version__.py')) as f:
    exec(f.read(), about)

with open('README.md', 'r') as f:
    readme = f.read()

setup(
    name="id10terr",
    description="Because it's necessary to have a package that helps you with your ID10T errors",
    long_description=readme,
    long_description_content_type='text/markdown',
    version="1.0.0",
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=find_packages(where="src"),
    include_package_data=True,
    python_requires=python_min_version,
    install_requires=required_packages,
    license=about['__license__'],
    zip_safe=True,
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    keywords='python ssh ai vibecoder junior interns sarcasm',
    entry_points = {}
)


"""Module information."""

import os

# The title and description of the package
__title__ = "id10terr"
__description__ = """
    ID10T python library
"""

# The version and build number
# Without specifying a unique number, you cannot overwrite packages in the PyPi repo
__version__ = os.getenv("RELEASE_NAME", "1.0.0")

# Author and license information
__author__ = "Scheibling Consulting"
__author_email__ = "itsec@scheibling.se"
__license__ = "GPL-3.0-or-later"

# URL to the project
__url__ = f"https://github.com/scheiblingco/{__title__}"